Revision History
================

1.2 (unreleased)
----------------

-  Added ``optional = true`` settings to downgrade errors to warnings.
-  Added ``message`` setting to display optional message for missing
   programs.

1.1 (2017/05/17)
----------------

-  Added ``--init`` command to generate a sample configuration file.

1.0 (2017/01/09)
----------------

-  Initial stable release.

0.5 (2016/11/02)
----------------

-  Added ``--exit-code`` option to return non-zero exit codes on
   failure.

0.4 (2016/10/20)
----------------

-  Added support for custom version arguments.
-  Fixed handling of internal versions matches.

0.3 (2016/10/18)
----------------

-  Added support for detecting missing and broken programs.

0.2.1 (2016/10/18)
------------------

-  Now stripping whitespace after calling ``--version`` on a program.

0.2 (2016/10/17)
----------------

-  Added ``--version`` command.

0.1 (2016/10/17)
----------------

-  Initial release.
